@@ -10,8 +10,8 @@
 
 #include "jobdouble.h"
 
-namespace Bugzilla {
-
+namespace Bugzilla
+{
 class ConnectionDouble : public Connection
 {
 public:
@@ -22,34 +22,26 @@ public:
         Q_UNREACHABLE();
     }
 
-    virtual APIJob *get(const QString &path,
-                        const QUrlQuery &query = QUrlQuery()) const override
+    virtual APIJob *get(const QString &path, const QUrlQuery &query = QUrlQuery()) const override
     {
         if (path == "/version") {
-            return new JobDouble { QFINDTESTDATA("data/bugzilla.version.json") };
+            return new JobDouble{QFINDTESTDATA("data/bugzilla.version.json")};
         } else if (path == "/login" && query.toString() == "login=auser&password=apass&restrict_login=true") {
-            return new JobDouble { QFINDTESTDATA("data/bugzilla.login.json") };
+            return new JobDouble{QFINDTESTDATA("data/bugzilla.login.json")};
         }
-        Q_ASSERT_X(false, "get",
-                   qUtf8Printable(QStringLiteral("unmapped: %1; %2").arg(path, query.toString())));
+        Q_ASSERT_X(false, "get", qUtf8Printable(QStringLiteral("unmapped: %1; %2").arg(path, query.toString())));
         return nullptr;
     }
 
-    virtual APIJob *post(const QString &path,
-                         const QByteArray &,
-                         const QUrlQuery &query = QUrlQuery()) const override
+    virtual APIJob *post(const QString &path, const QByteArray &, const QUrlQuery &query = QUrlQuery()) const override
     {
-        Q_ASSERT_X(false, "post",
-                   qUtf8Printable(QStringLiteral("unmapped: %1; %2").arg(path, query.toString())));
+        Q_ASSERT_X(false, "post", qUtf8Printable(QStringLiteral("unmapped: %1; %2").arg(path, query.toString())));
         return nullptr;
     }
 
-    virtual APIJob *put(const QString &path,
-                        const QByteArray &,
-                        const QUrlQuery &query = QUrlQuery()) const override
+    virtual APIJob *put(const QString &path, const QByteArray &, const QUrlQuery &query = QUrlQuery()) const override
     {
-        Q_ASSERT_X(false, "put",
-                   qUtf8Printable(QStringLiteral("unmapped: %1; %2").arg(path, query.toString())));
+        Q_ASSERT_X(false, "put", qUtf8Printable(QStringLiteral("unmapped: %1; %2").arg(path, query.toString())));
         return nullptr;
     }
 };
